#!/bin/bash
# This is a script to build a Zenwalk package. Check the Zenwalk homepage: www.zenwalk.org
#
# SOFTWARE			: emelfm2
# MAINTAINER       	: skywatcher (s.skywatcher|AT|gmail|DOT|org, simone antoniucci)
# LATEST REVISION	: 2011-02-13
# BUILD-ONLY DEPS	: -
# NOTES				: -

### Checking for unbound variables and exit on errors
set -u -e

### Repo
URL=http://zenwalk.pinguix.com/user-accounts/skywatcher

### Pkg variables
NAME="emelfm2"
VERSION="0.7.5"
ARCH="i686"
CPU="i686"
BUILD="70.1"
EXT="txz"
HOMEPAGE="http://emelfm2.net/emelFM2"
SRCLNK="http://emelfm2.net/rel/$NAME-$VERSION.tar.bz2"
DESCRIPTION="Two-panes file manager"
ADDSRC=""
INCSRC=""
ADDDEP=""
XCLDEP=""

### Script variables
CWD=`pwd`
PKG=$NAME-$VERSION-$ARCH-$BUILD
URL=$URL/$NAME/$VERSION
PKGDIR=$CWD/$NAME-install
SRCDIR=$CWD/$NAME-$VERSION
SRCPKG=`echo $SRCLNK | cut -d\  -f1 | rev | cut -d/ -f1 | rev`

### Flags and jobs
export CFLAGS="-O2 -march=$ARCH -mtune=$CPU"
export CXXFLAGS="-O2 -march=$ARCH -mtune=$CPU"
NJOBS="-j4"

### Cleaning
rm -rf $PKGDIR
rm -rf $SRCDIR

### Making default package dirs
install -dv $SRCDIR $PKGDIR/{install,usr/src/$NAME-$VERSION}

### Getting sources
for src in $SRCLNK; do \
	source=`echo $src | rev | cut -d/ -f1 | rev` 
	if [ -f $source ]; then
		echo "Source file $source is already present, no need to download it";
	else
		echo "Downloading $source..."
		wget -c -nv $SRCLNK
	fi
done

### Extracting main sources
tar xfv $SRCPKG -C $SRCDIR --strip-components=1

### Building ===========================================================
cd $SRCDIR

# Modifying files
sed -i "s@/doc/\$(TARGET)@/doc/$NAME-$VERSION@g" Makefile.config
sed -i "s|USE_GAMIN ?= 0|USE_GAMIN ?= 1|g" Makefile.config
sed -i "s|/share/pixmaps/|/share/|g" Makefile.config
sed -i "s|/share/man/man1|/man/man1|g" Makefile.config
sed -i "s|/share/doc/|/doc/|g" Makefile.config

# Compiling and installing
make $NJOBS PREFIX=/usr DOC_DIR=/usr/doc/$NAME-$VERSION || exit 1
make install PREFIX=$PKGDIR/usr || exit 1

# Icon
install -dv $PKGDIR/usr/share/icons/hicolor/48x48/apps
ln -sv "/usr/share/$NAME/emelfm2_48.png" "$PKGDIR/usr/share/icons/hicolor/48x48/apps/emelfm2.png"

# Desktop entry
sed -i "s|Icon=emelfm2/emelfm2_48.png|Icon=emelfm2|" $PKGDIR/usr/share/applications/$NAME.desktop
sed -i "s|Categories=System;FileTools;GTK;FileManager;|Categories=Utility;FileTools;FileManager;GTK;|" $PKGDIR/usr/share/applications/$NAME.desktop

# Docs, man, info
#cd $SRCDIR
#install -dv $PKGDIR/usr/doc/$NAME-$VERSION
#install -v $DOCS $PKGDIR/usr/doc/$NAME-$VERSION

# Unnedeed stuff

### Slack-desc 
#    |-----handy-ruler------------------------------------------------------|
cat > $PKGDIR/install/slack-desc << EOF
$NAME: $NAME - $DESCRIPTION
$NAME:  
$NAME: Emelfm 2 is a light-weight and higly configurable file manager 
$NAME: for UNIX-like operating systems. It uses a simple and efficient 
$NAME: interface pioneered by Norton Commander in the '80s, in which the 
$NAME: main window is divided into panes.
$NAME: A built-in command-line, toolbar buttons or assigned keys can be 
$NAME: used to initiate commands. 
$NAME: 
$NAME: 
$NAME: $HOMEPAGE
EOF

### Doinstall

# ======================================================================

### Managing and zipping man and info files
if [ -d $PKGDIR/usr/man ]; then
	find $PKGDIR/usr/man -type f -exec gzip -9 -v {} \;
fi
if [ -d $PKGDIR/usr/info ]; then
	find $PKGDIR/usr/info -type f -exec gzip -9 -v {} \;
fi

### Adding build-file and included stuff to the package
for file in $0 $INCSRC
	do cp -av $CWD/$file $PKGDIR/usr/src/$NAME-$VERSION
done
chmod a+x $PKGDIR/usr/src/$NAME-$VERSION/build-$NAME.sh

### Stripping binaries
cd $PKGDIR
set +e
find . | xargs file | grep "executable" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
find . | xargs file | grep "shared object" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null

### Ownerships and permissions
cd $PKGDIR
chown -R root:root .
find . -perm 666 -exec chmod 644 {} \;
find . -perm 664 -exec chmod 644 {} \;
find . -perm 600 -exec chmod 644 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 400 -exec chmod 644 {} \;
find . -perm 440 -exec chmod 644 {} \;
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 511 -exec chmod 755 {} \;
find . -perm 711 -exec chmod 755 {} \;
find . -perm 555 -exec chmod 755 {} \;
set -e

### Making the package
makepkg -l y -c n $CWD/$PKG.$EXT
cd $CWD

### md5
md5sum $PKG.$EXT > $PKG.md5

### dep
ADD=$ADDDEP EXCLUDE=$XCLDEP requiredbuilder -z $PKG.$EXT > $PKG.dep

### slackdesc
cat $PKGDIR/install/slack-desc > $PKG.txt

### src
echo $SRCLNK > $PKG.src
for link in $0 $ADDSRC 
	do echo $URL/$link >> $PKG.src
done

### Cleaning
DEL_SRCDIR=${DEL_SRCDIR-1}
if [ "$DEL_SRCDIR" -eq "1" ]; then
	rm -rf $SRCDIR
	rm -rf $PKGDIR
fi

### Done. Ciao!
